ytree\.arbor\.fields\.FieldContainer
====================================

.. currentmodule:: ytree.arbor.fields

.. autoclass:: FieldContainer

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~FieldContainer.__init__
      ~FieldContainer.clear
      ~FieldContainer.copy
      ~FieldContainer.fromkeys
      ~FieldContainer.get
      ~FieldContainer.items
      ~FieldContainer.keys
      ~FieldContainer.pop
      ~FieldContainer.popitem
      ~FieldContainer.setdefault
      ~FieldContainer.update
      ~FieldContainer.values
   
   

   
   
   